# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.1.2

([Full Changelog](https://github.com/jupyter-ai-contrib/jupyter-server-documents/compare/v0.1.1...3ae9d06e5a829b36010be9239f184ff97d001fa9))

### Bugs fixed

- Clears outputs on each execute [#207](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/207) ([@3coins](https://github.com/3coins), [@dlqqq](https://github.com/dlqqq))

### Contributors to this release

The following people contributed discussions, new ideas, code and documentation contributions, and review.
See [our definition of contributors](https://github-activity.readthedocs.io/en/latest/use/#how-does-this-tool-define-contributions-in-the-reports).

([GitHub contributors page for this release](https://github.com/jupyter-ai-contrib/jupyter-server-documents/graphs/contributors?from=2026-03-24&to=2026-03-30&type=c))

@3coins ([activity](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3A3coins+updated%3A2026-03-24..2026-03-30&type=Issues)) | @dlqqq ([activity](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3Adlqqq+updated%3A2026-03-24..2026-03-30&type=Issues))

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.1.1

([Full Changelog](https://github.com/jupyter-ai-contrib/jupyter-server-documents/compare/v0.1.0...2c8a4de745d52d4eee13d2af18686d6ca1591f17))

### Bugs fixed

- Fix cell duplication on out-of-band file changes by reloading file content in-place [#202](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/202) ([@sathishlxg](https://github.com/sathishlxg), [@3coins](https://github.com/3coins), [@Zsailer](https://github.com/Zsailer), [@dlqqq](https://github.com/dlqqq))
- Add ping/pong keepalive to YRoomWebsocket [#201](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/201) ([@dlqqq](https://github.com/dlqqq), [@Zsailer](https://github.com/Zsailer))

### Contributors to this release

The following people contributed discussions, new ideas, code and documentation contributions, and review.
See [our definition of contributors](https://github-activity.readthedocs.io/en/latest/use/#how-does-this-tool-define-contributions-in-the-reports).

([GitHub contributors page for this release](https://github.com/jupyter-ai-contrib/jupyter-server-documents/graphs/contributors?from=2026-01-15&to=2026-03-24&type=c))

@3coins ([activity](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3A3coins+updated%3A2026-01-15..2026-03-24&type=Issues)) | @dlqqq ([activity](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3Adlqqq+updated%3A2026-01-15..2026-03-24&type=Issues)) | @sathishlxg ([activity](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3Asathishlxg+updated%3A2026-01-15..2026-03-24&type=Issues)) | @Zsailer ([activity](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3AZsailer+updated%3A2026-01-15..2026-03-24&type=Issues))

## 0.1.0

([Full Changelog](https://github.com/jupyter-ai-contrib/jupyter-server-documents/compare/v0.1.0a9...a65fd2129eca2e844fa02590020af8a2f7159fd3))

### Enhancements made

- Disable OOB change notification [#187](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/187) ([@dlqqq](https://github.com/dlqqq), [@ellisonbg](https://github.com/ellisonbg))

### Bugs fixed

- Remove save toolbar buttons [#180](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/180) ([@nakul-py](https://github.com/nakul-py), [@dlqqq](https://github.com/dlqqq))

### Maintenance and upkeep improvements

- Update verbose logs to debug level [#181](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/181) ([@3coins](https://github.com/3coins), [@dlqqq](https://github.com/dlqqq))

### Other merged PRs

- Fix metadata links [#184](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/184) ([@ktaletsk](https://github.com/ktaletsk), [@dlqqq](https://github.com/dlqqq))

### Contributors to this release

The following people contributed discussions, new ideas, code and documentation contributions, and review.
See [our definition of contributors](https://github-activity.readthedocs.io/en/latest/#how-does-this-tool-define-contributions-in-the-reports).

([GitHub contributors page for this release](https://github.com/jupyter-ai-contrib/jupyter-server-documents/graphs/contributors?from=2025-11-18&to=2026-01-15&type=c))

@3coins ([activity](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3A3coins+updated%3A2025-11-18..2026-01-15&type=Issues)) | @dlqqq ([activity](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3Adlqqq+updated%3A2025-11-18..2026-01-15&type=Issues)) | @ellisonbg ([activity](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3Aellisonbg+updated%3A2025-11-18..2026-01-15&type=Issues)) | @ktaletsk ([activity](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3Aktaletsk+updated%3A2025-11-18..2026-01-15&type=Issues)) | @nakul-py ([activity](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3Anakul-py+updated%3A2025-11-18..2026-01-15&type=Issues))

## 0.1.0a9

([Full Changelog](https://github.com/jupyter-ai-contrib/jupyter-server-documents/compare/v0.1.0a8...dccb851a90d057da08c55a9c7e4d4da77bb80c8b))

### Enhancements made

- Remove excessive sync message logging [#172](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/172) ([@Zsailer](https://github.com/Zsailer))

### Bugs fixed

- Replace CRLF with LF when loading file [#177](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/177) ([@dlqqq](https://github.com/dlqqq))
- Fixes server error when deleted rooms are saved at shutdown [#175](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/175) ([@3coins](https://github.com/3coins))

### Documentation improvements

- docs: fix small typo [#173](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/173) ([@rgbkrk](https://github.com/rgbkrk))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-ai-contrib/jupyter-server-documents/graphs/contributors?from=2025-10-23&to=2025-11-18&type=c))

[@3coins](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3A3coins+updated%3A2025-10-23..2025-11-18&type=Issues) | [@dlqqq](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3Adlqqq+updated%3A2025-10-23..2025-11-18&type=Issues) | [@rgbkrk](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3Argbkrk+updated%3A2025-10-23..2025-11-18&type=Issues) | [@Zsailer](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3AZsailer+updated%3A2025-10-23..2025-11-18&type=Issues)

## 0.1.0a8

([Full Changelog](https://github.com/jupyter-ai-contrib/jupyter-server-documents/compare/v0.1.0a7...dcf8a50078d525356737c69a94ca919281c2e379))

### Enhancements made

- Cleanup and add validation to new adaptive saving strategy [#169](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/169) ([@dlqqq](https://github.com/dlqqq))
- Refactor OutputsManager to align with default Jupyter behavior [#163](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/163) ([@ellisonbg](https://github.com/ellisonbg))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-ai-contrib/jupyter-server-documents/graphs/contributors?from=2025-10-22&to=2025-10-23&type=c))

[@3coins](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3A3coins+updated%3A2025-10-22..2025-10-23&type=Issues) | [@dlqqq](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3Adlqqq+updated%3A2025-10-22..2025-10-23&type=Issues) | [@ellisonbg](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3Aellisonbg+updated%3A2025-10-22..2025-10-23&type=Issues)

## 0.1.0a7

([Full Changelog](https://github.com/jupyter-ai-contrib/jupyter-server-documents/compare/v0.1.0a6...a1dbf46fc33e3e02fe475b3f197d1e17501d3374))

### Enhancements made

- Rename NPM package [#166](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/166) ([@dlqqq](https://github.com/dlqqq))
- Handle YChat document resets when `jupyterlab_chat` is installed [#161](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/161) ([@dlqqq](https://github.com/dlqqq))

### Bugs fixed

- Track if files are writable and disable saving if they are not. [#164](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/164) ([@ellisonbg](https://github.com/ellisonbg))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-ai-contrib/jupyter-server-documents/graphs/contributors?from=2025-10-14&to=2025-10-22&type=c))

[@3coins](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3A3coins+updated%3A2025-10-14..2025-10-22&type=Issues) | [@dlqqq](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3Adlqqq+updated%3A2025-10-14..2025-10-22&type=Issues) | [@ellisonbg](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3Aellisonbg+updated%3A2025-10-14..2025-10-22&type=Issues)

## 0.1.0a6

([Full Changelog](https://github.com/jupyter-ai-contrib/jupyter-server-documents/compare/10c176a76ac7595a299d4ccb4ccfb57c283c2182...bc6b60d58f569e77ab828ffe3cccff2d09a83675))

### Enhancements made

- Add optional `on_reset` argument to `YRoom` get methods [#152](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/152) ([@dlqqq](https://github.com/dlqqq))

### Bugs fixed

- Fixing lint error [#159](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/159) ([@3coins](https://github.com/3coins))
- Fix real-time output clearing for collaborative editing [#150](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/150) ([@ellisonbg](https://github.com/ellisonbg))

### Documentation improvements

- Add `CLAUDE.md` and `AGENTS.md` [#154](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/154) ([@dlqqq](https://github.com/dlqqq))

### Other merged PRs

- Increase stream limit to 200 [#149](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/149) ([@ellisonbg](https://github.com/ellisonbg))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-ai-contrib/jupyter-server-documents/graphs/contributors?from=2025-07-25&to=2025-10-14&type=c))

[@3coins](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3A3coins+updated%3A2025-07-25..2025-10-14&type=Issues) | [@dlqqq](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3Adlqqq+updated%3A2025-07-25..2025-10-14&type=Issues) | [@ellisonbg](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3Aellisonbg+updated%3A2025-07-25..2025-10-14&type=Issues)
